<?php

class Postbar_API 
{

    // callAPI
    public static function callAPI($method, $endpoint, $data, $headers)
    {
        $base_url = 'https://api.postchi.app/';
        $url = $base_url.$endpoint;
        $body = wp_json_encode($data);
        $args = array(
            'method' => $method,
            'body' => $body,
            'headers' => $headers,
            'timeout' => 300
        );
        $response = wp_remote_request( $url, $args );

        if(!is_wp_error($response) && ($response['response']['code'] == 200 || $response['response']['code'] == 201)) 
        {
            return json_decode($response['body']);
        }
        else 
        {
            return false;
        }
    }
    // End: callAPI
    
    // Login
    public static function login($username, $password)
    {
        $method = 'POST';
        $endpoint = 'user/login';
        $data = array('username' => $username, 'password' => $password);
        $headers = '';

        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);
 
        $response = new stdClass();
        if($result_obj->result === false)
        {   
            $response->success = 0;
            $response->errors = [$result_obj->message];
        }
        else
        {
            $response->success = 1;
            $response->data = $result_obj->objects;
        }

        return $response;
    }
    // End: Login

    // Get Token
    public static function getToken()
    {
        $method = 'POST';
        $endpoint = "user/check_token";
        $token = get_option('postchi_woo_shipping_token');
        $data = array();
        $headers = array('auth' => $token);

        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);

        if($result_obj->result == false)
        {
            $postchi_username = get_option('postchi_woo_shipping_opts')["postchi_username"];
            $postchi_password = get_option('postchi_woo_shipping_opts')["postchi_password"];
            $postchi_user_data = Postbar_API::login($postchi_username, $postchi_password);
            if($postchi_user_data->success && $postchi_user_data->data->user->token)
            {
                update_option( 'postchi_woo_shipping_token', $postchi_user_data->data->user->token );
                $token = get_option('postchi_woo_shipping_token');
            }
        }


        return $token;
    }
    // End: Get Token
    
    // Get States
    public static function getState()
    {
        $method = "POST";
        $endpoint = 'region/query';
        $data = '{"fields": "fld_Region_No,fld_Region_Name","where":"1","suspend":false,"sort_by":"fld_Region_Name","sort_type":"ASC","limit": "0, 300"}';
        $headers = 'auth:'.Postbar_API::getToken();
        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);
        $response = new stdClass();
        if(!$result_obj->result) 
        {   
            $response->success = 0;
        }
        else
        {
            $response->success = 1;
            $response->data = $result_obj->objects[0];
        }

        return $response;
    }


        // Get States
        public static function getTermsAndConditions()
        {
            $method = "POST";
            $endpoint = 'service/fetch_terms_of_service';
            $data = '';
            $headers = 'auth:'.Postbar_API::getToken();
            $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);
            $response = new stdClass();
            if(!$result_obj->result) 
            {   
                $response->success = 0;
            }
            else
            {
                $response->success = 1;
                $response->data = $result_obj->objects;
            }
    
            return $response;
        }

    // Get States   
    
    // Get Towns By StateId
    public static function getTownsByStateId($stateId)
    {
        $method = 'POST';
        $endpoint = 'city/query';
        $data = array("fields"=> "fld_City_No,fld_Code","where"=>"fld_Region_No=".$stateId,"suspend"=>false,"sort_by"=>"fld_Code","sort_type"=>"ASC","limit"=> "0, 300");
        $headers = 'auth:'.Postbar_API::getToken();
        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);
        $response = new stdClass();
        if($result_obj->result == false) 
        {   
            $response->success = 0;
        }
        else
        {
            $response->success = 1;
            $response->data = $result_obj->objects[0]->city;
        }

        return $response;
    }
    // End: Get Towns By StateId

    // Get Services
    public static function getServices($data_array)
    {
        $method = 'POST';
        $endpoint = 'order/quote';
        $data = $data_array;
        $headers = 'auth:'.Postbar_API::getToken();

        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);

        $response = new stdClass();
        if($result_obj->result == false)
        {   
            $response->success = 0;
            $response->errors = $result_obj->message;
        }
        else
        {
            $response->success = 1;
            $response->data = $result_obj->objects->courier;
        }

        $response->result = $result_obj->result;

        return $response;
    }
    // End: Get Services

    // Get Insurance List
    public function getInsuranceList($serviceId)
    {
        $method = 'GET';
        $endpoint = 'getInsuranceList';
        $data = array('serviceId' => $serviceId);
        $headers = 'token:'.Postbar_API::getToken();

        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);

        $response = new stdClass();
        if(!$result_obj) 
        {   
            $response->success = 0;
        }
        else
        {
            $response->success = 1;
            $response->data = $result_obj;
        }

        return $response;
    }
    // End: Get Insurance List

    // Get CartonSize List
    public function getCartonSizeList($serviceId)
    {
        $method = 'GET';
        $endpoint = 'getCartonSizeList';
        $data = array('serviceId' => $serviceId);
        $headers = 'token:'.Postbar_API::getToken();

        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);

        $response = new stdClass();
        if(!$result_obj) 
        {   
            $response->success = 0;
        }
        else
        {
            $response->success = 1;
            $response->data = $result_obj;
        }

        return $response;
    }
    // End: Get CartonSize List
    
    // Get CartonSize List
    public function getPrice($data_array)
    {
        $method = 'POST';
        $endpoint = 'getPrice';
        $data = $data_array;
        $headers = 'token:'.Postbar_API::getToken();

        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);

        $response = new stdClass();
        if(!$result_obj) 
        {   
            $response->success = 0;
        }
        else
        {
            $response->success = 1;
            $response->data = $result_obj;
        }

        return $response;
    }
    // End: Get CartonSize List

    // New Order
    public function newOrder($data_array)
    {
        $method = 'POST';
        $endpoint = 'order/make_saman_payment';
        $data = $data_array;
        $headers = 'auth:'.Postbar_API::getToken();

        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);

        $response = new stdClass();
        if($result_obj->result == false) 
        {   
            $response->errors = $result_obj->message;
            $response->success = 0;
        }
        else
        {
            $response->success = 1;
            $response->data = $result_obj->objects;
        }

        return $response;
    }
    // End: New Order

    // Get Wallet Charge
    public function getWalletChargeRate($mobileNo)
    {
        $method = 'GET';
        $endpoint = 'customer/getWalletChargeRate';
        $data = array( "mobileNo" => $mobileNo);
        $headers = 'token:'.Postbar_API::getToken();

        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);

        $response = new stdClass();
        if(!$result_obj) 
        {   
            $response->success = 0;
        }
        else
        {
            $response->success = 1;
            $response->data = $result_obj;
        }

        return $response;
    }
    // End: Get Wallet Charge

    // Order Tracking
    public static function orderTracking($orderId)
    {
        $method = 'POST';
        $endpoint = "order/fetch_order";
        $data = array("trackingId" => $orderId);
        $headers = 'auth:'.Postbar_API::getToken();

        $result_obj = Postbar_API::callAPI($method, $endpoint, $data, $headers);

        $response = new stdClass();
        if($result_obj->result == false) 
        {   
            $response->success = 0;
        }
        else
        {
            $response->success = 1;


            foreach ($result_obj->objects as $order) {
                if ($order->package->tracking == $orderId) {
                    $response->data = $order;  
                }
            }

        }

        return $response;
    }
    // End : Order Tracking
    
}
// End: Postbar_API Class
